# Changelog

All notable changes to the VideoBGRemover Python SDK will be documented in this file.

## [0.1.2] - 2025-09-27

### Changed
- Clean up README with accurate examples and documentation
- Clean RemoveBGOptions API

## [0.1.1] - 2025-09-27

### Added
- Initial release of VideoBGRemover Python SDK
- Video background removal with AI
- Multi-layer video composition system
- Support for transparent video formats (WebM VP9, ProRes, Stacked Video, PNG Sequence)
- FFmpeg integration for video processing

[0.1.1]: https://github.com/videobgremover/videobgremover-python/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/videobgremover/videobgremover-python/releases/tag/v0.1.0
